#
# spec file for package maven-shared-utils
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           maven-shared-utils
Version:        3.4.2
Release:        1.4
Summary:        Maven shared utility classes
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://maven.apache.org/shared/maven-shared-utils
Source0:        https://repo1.maven.org/maven2/org/apache/maven/shared/%{name}/%{version}/%{name}-%{version}-source-release.zip
Source1:        %{name}-build.xml
# XXX temporary for maven upgrade
Patch0:         0001-Restore-compatibility-with-current-maven.patch
BuildRequires:  ant
BuildRequires:  apache-commons-io
BuildRequires:  fdupes
BuildRequires:  jansi
BuildRequires:  javapackages-local >= 6
BuildRequires:  jsr-305
BuildRequires:  slf4j
BuildRequires:  unzip
BuildArch:      noarch

%description
This project aims to be a functional replacement for plexus-utils in Maven.

It is not a 100% API compatible replacement though but a replacement with
improvements: lots of methods got cleaned up, generics got added and we dropped
a lot of unused code.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
API documentation for %{name}.

%prep
%setup -q
%patch -P 0 -p1
cp %{SOURCE1} build.xml

%build
mkdir -p lib
build-jar-repository -s lib commons-io jansi/jansi slf4j/api jsr305

%{ant} \
  jar javadoc

%install
# jar
install -dm 0755 %{buildroot}%{_javadir}/%{name}
install -pm 0644 target/%{name}-%{version}.jar %{buildroot}%{_javadir}/%{name}/%{name}.jar
# pom
install -dm 0755 %{buildroot}%{_mavenpomdir}/%{name}
%{mvn_install_pom} pom.xml %{buildroot}%{_mavenpomdir}/%{name}/%{name}.pom
%add_maven_depmap %{name}/%{name}.pom %{name}/%{name}.jar
# javadoc
install -dm 0755 %{buildroot}%{_javadocdir}/%{name}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}/
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE NOTICE

%files javadoc
%license LICENSE NOTICE
%{_javadocdir}/%{name}

%changelog
* Tue Jun 18 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 3.4.2
  * New features and improvements
    + [MNG-7729] - deprecate questionable IsEmpty/IsNotEmpty methods
    + [MSHARED-1014] - Make Commandline.addSystemEnvironment public
    and deprecated
    + Deprecate newXmlWriter
    + [MSHARED-1172] - Deprecate redundant isEmptyString method
    + [MSHARED-1169] - deprecate join methods now available in
    Java 8 String class
    + [MSHARED-1122] - FileUtils: avoid getCanonicalPath()
    + [MSHARED-1079] - add build() method and document toString()
    method
    + [MSHARED-1014] - Optionally inherit system environment
    variables by Commandline
    + [MSHARED-983] - Drop plexus container default
  * Bug Fixes
    + [MSHARED-953] - don't trim
    + [MSHARED-1072] - fix blocking in StreamFeeder
    + [MSHARED-1109] - Ignore MessageUtilsTest methods on
    unsupported platforms
    + [MSHARED-1107] - Make copyFile succeed with source file
    having lastModified() = 0
    + [MSHARED-985] - XmlWriterUtil platform independent and
    consistent
    + [MSHARED-1072] - Poll data from input stream
- Modified patch:
  * 0001-Restore-compatibility-with-current-maven.patch
    + rediff to changed context
* Sun May 26 2024 Fridrich Strba <fstrba@suse.com>
- Use the org.eclipse.sisu:org.eclipse.sisu.plexus artifact in
  order to avoid conflict/choise of providers
* Wed Feb 21 2024 Fridrich Strba <fstrba@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Wed May  3 2023 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 3.3.4
  * Bug
    + [MSHARED-951] - Checked exception converted to raw runtime
    exception
    + [MSHARED-952] - PrettyPrintXmlWriter output is platform
    dependent
    + [MSHARED-954] - Deprecate StringUtils.unifyLineSeparator
    + [MSHARED-969] - Environment variable with null value
  * Dependency upgrade
    + [MSHARED-962] - Upgrade Jansi to 2.0.1
    + [MSHARED-973] - Upgrade Jansi to 2.2.0
- Changed patch:
  * 0001-Restore-compatibility-with-current-maven.patch
    + rediff to changed context/line-ends
* Mon Apr 25 2022 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 3.3.3
  * Bug
    + [MSHARED-297] - Commandline class shell injection
    vulnerabilities (bsc#1198833, CVE-2022-29599)
    + [MSHARED-416] - Odd number of quotes in command-line fails
    + [MSHARED-431] - # (Hash-Sign) should trigger quoting in
    BourneShell.java
    + [MSHARED-681] - Maven-Shared: Java7Support silently fails
    overwriting symlinks
    + [MSHARED-749] - Commandline does not thrown
    CommandLineException when uneven number of quotation marks
    used
    + [MSHARED-750] - Unbalanced quotes in command with escaped
    double quotation mark
  * Improvement
    + [MSHARED-684] - Upgrade parent to 31
    + [MSHARED-748] - Upgrade maven-shared-parent to 32
    + [MSHARED-826] - Require Java 7
    + [MSHARED-879] - make build Reproducible
    + [MSHARED-881] - try with resources in FileUtils
* Sun Mar 20 2022 Fridrich Strba <fstrba@suse.com>
- Build with source and target levels 8
* Thu Mar 14 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of maven-shared-utils 3.2.1
- Generate and customize ant build.xml
